Index: trunk/psLib/src/image/psImage.h
===================================================================
--- trunk/psLib/src/image/psImage.h	(revision 2105)
+++ trunk/psLib/src/image/psImage.h	(revision 2204)
@@ -11,6 +11,6 @@
  *  @author Ross Harman, MHPCC
  *
- *  @version $Revision: 1.41 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-10-14 01:22:59 $
+ *  @version $Revision: 1.42 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-27 00:57:31 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -47,8 +47,8 @@
 {
     const psType type;                 ///< Image data type and dimension.
-    const unsigned int numCols;        ///< Number of columns in image
-    const unsigned int numRows;        ///< Number of rows in image.
-    const int col0;                    ///< Column position relative to parent.
-    const int row0;                    ///< Row position relative to parent.
+    const psU32 numCols;        ///< Number of columns in image
+    const psU32 numRows;        ///< Number of rows in image.
+    const psS32 col0;                    ///< Column position relative to parent.
+    const psS32 row0;                    ///< Row position relative to parent.
 
     union {
@@ -65,11 +65,11 @@
         psC32** C32;                   ///< Single-precision complex data.
         psC64** C64;                   ///< Double-precision complex data.
-        psPTR** PTR;                   ///< Void pointers.
-        psPTR*  V;                     ///< Pointer to data.
+        psPtr** PTR;                   ///< Void pointers.
+        psPtr*  V;                     ///< Pointer to data.
     } data;                            ///< Union for data types.
     const struct psImage* parent;      ///< Parent, if a subimage.
     psArray* children;                 ///< Children of this region.
 
-    void* rawDataBuffer;
+    psPtr rawDataBuffer;
 }
 psImage;
@@ -84,6 +84,6 @@
  */
 psImage* psImageAlloc(
-    unsigned int numCols,              ///< Number of rows in image.
-    unsigned int numRows,              ///< Number of columns in image.
+    psU32 numCols,              ///< Number of rows in image.
+    psU32 numRows,              ///< Number of columns in image.
     const psElemType type              ///< Type of data for image.
 );
@@ -96,6 +96,6 @@
 psImage* psImageRecycle(
     psImage* old,                      ///< the psImage to recycle by resizing image buffer
-    unsigned int numCols,              ///< the desired number of columns in image
-    unsigned int numRows,              ///< the desired number of rows in image
+    psU32 numCols,              ///< the desired number of columns in image
+    psU32 numRows,              ///< the desired number of rows in image
     const psElemType type              ///< the desired datatype of the image
 );
@@ -115,8 +115,8 @@
 /** Frees all children of a psImage.
  *
  *  @return int      Number of children freed.
  *
  */
-int psImageFreeChildren(
+psS32 psImageFreeChildren(
     psImage* image                     ///< psImage in which all children shall be deallocated
 );
@@ -132,5 +132,5 @@
     float y,                           ///< row location ot derive value of
     const psImage* mask,               ///< if not NULL, the mask of the input image
-    unsigned int maskVal,              ///< the mask value
+    psU32 maskVal,              ///< the mask value
     psC64 unexposedValue,              ///< return value if x,y location is not in image.
     psImageInterpolateMode mode        ///< interpolation mode
@@ -143,5 +143,5 @@
         float y,                       /**< row location ot derive value of */ \
         const psImage* mask,           /**< if not NULL, the mask of the input image */ \
-        unsigned int maskVal,          /**< the mask value */ \
+        psU32 maskVal,          /**< the mask value */ \
         psF64 unexposedValue           /**< return value if x,y location is not in image. */ \
                                                  ); \
@@ -151,5 +151,5 @@
         float y,                       /**< row location ot derive value of */ \
         const psImage* mask,           /**< if not NULL, the mask of the input image */ \
-        unsigned int maskVal,          /**< the mask value */ \
+        psU32 maskVal,          /**< the mask value */ \
         psF64 unexposedValue           /**< return value if x,y location is not in image. */ \
                                                      );
@@ -161,5 +161,5 @@
         float y,                       /**< row location ot derive value of */ \
         const psImage* mask,           /**< if not NULL, the mask of the input image */ \
-        unsigned int maskVal,          /**< the mask value */ \
+        psU32 maskVal,          /**< the mask value */ \
         psC64 unexposedValue           /**< return value if x,y location is not in image. */ \
                                                  ); \
@@ -169,5 +169,5 @@
         float y,                       /**< row location ot derive value of */ \
         const psImage* mask,           /**< if not NULL, the mask of the input image */ \
-        unsigned int maskVal,          /**< the mask value */ \
+        psU32 maskVal,          /**< the mask value */ \
         psC64 unexposedValue           /**< return value if x,y location is not in image. */ \
                                                      );
@@ -115,8 +115,8 @@
 /** Frees all children of a psImage.
  *
- *  @return int      Number of children freed.
+ *  @return psS32      Number of children freed.
  *
  */
